aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--build/database.js2
-rw-r--r--build/hypixelCached.js8
-rw-r--r--src/database.ts2
-rw-r--r--src/hypixelCached.ts8
4 files changed, 10 insertions, 10 deletions
diff --git a/build/database.js b/build/database.js
index 25f0b24..647c853 100644
--- a/build/database.js
+++ b/build/database.js
@@ -247,7 +247,7 @@ async function updateDatabaseMember(member, profile) {
}
exports.updateDatabaseMember = updateDatabaseMember;
const queue = new queue_promise_1.default({
- concurrent: 10,
+ concurrent: 1,
interval: 500
});
/** Queue an update for the member's leaderboard data on the server if applicable */
diff --git a/src/database.ts b/src/database.ts
index 09288e5..5d97e88 100644
--- a/src/database.ts
+++ b/src/database.ts
@@ -274,7 +274,7 @@ export async function updateDatabaseMember(member: CleanMember, profile: CleanFu
}
const queue = new Queue({
- concurrent: 10,
+ concurrent: 1,
interval: 500
})
diff --git a/build/hypixelCached.js b/build/hypixelCached.js
index d41da97..3ef40ec 100644
--- a/build/hypixelCached.js
+++ b/build/hypixelCached.js
@@ -68,7 +68,7 @@ const profileNameCache = new node_cache_1.default({
checkperiod: 60,
useClones: false,
});
-function waitForSet(cache, key, value) {
+function waitForCacheSet(cache, key, value) {
return new Promise((resolve, reject) => {
const listener = (setKey, setValue) => {
if (setKey === key || (value && setValue === value)) {
@@ -90,7 +90,7 @@ async function uuidFromUser(user) {
if (usernameCache.has(util_1.undashUuid(user))) {
// check if the uuid is a key
const username = usernameCache.get(util_1.undashUuid(user));
- // if it has .then, then that means its a waitForSet promise. This is done to prevent requests made while it is already requesting
+ // if it has .then, then that means its a waitForCacheSet promise. This is done to prevent requests made while it is already requesting
if (username.then) {
const { key: uuid, value: _username } = await username;
usernameCache.set(uuid, _username);
@@ -107,8 +107,8 @@ async function uuidFromUser(user) {
}
if (_1.debug)
console.log('Cache miss: uuidFromUser', user);
- // set it as waitForSet (a promise) in case uuidFromUser gets called while its fetching mojang
- usernameCache.set(util_1.undashUuid(user), waitForSet(usernameCache, user, user));
+ // set it as waitForCacheSet (a promise) in case uuidFromUser gets called while its fetching mojang
+ usernameCache.set(util_1.undashUuid(user), waitForCacheSet(usernameCache, user, user));
// not cached, actually fetch mojang api now
let { uuid, username } = await mojang.mojangDataFromUser(user);
if (!uuid) {
diff --git a/src/hypixelCached.ts b/src/hypixelCached.ts
index f76c52a..483b3fa 100644
--- a/src/hypixelCached.ts
+++ b/src/hypixelCached.ts
@@ -54,7 +54,7 @@ const profileNameCache = new NodeCache({
useClones: false,
})
-function waitForSet(cache: NodeCache, key?: string, value?: string): Promise<any> {
+function waitForCacheSet(cache: NodeCache, key?: string, value?: string): Promise<any> {
return new Promise((resolve, reject) => {
const listener = (setKey, setValue) => {
if (setKey === key || (value && setValue === value)) {
@@ -78,7 +78,7 @@ export async function uuidFromUser(user: string): Promise<string> {
if (usernameCache.has(undashUuid(user))) {
// check if the uuid is a key
const username: any = usernameCache.get(undashUuid(user))
- // if it has .then, then that means its a waitForSet promise. This is done to prevent requests made while it is already requesting
+ // if it has .then, then that means its a waitForCacheSet promise. This is done to prevent requests made while it is already requesting
if (username.then) {
const { key: uuid, value: _username } = await username
usernameCache.set(uuid, _username)
@@ -96,8 +96,8 @@ export async function uuidFromUser(user: string): Promise<string> {
if (debug) console.log('Cache miss: uuidFromUser', user)
- // set it as waitForSet (a promise) in case uuidFromUser gets called while its fetching mojang
- usernameCache.set(undashUuid(user), waitForSet(usernameCache, user, user))
+ // set it as waitForCacheSet (a promise) in case uuidFromUser gets called while its fetching mojang
+ usernameCache.set(undashUuid(user), waitForCacheSet(usernameCache, user, user))
// not cached, actually fetch mojang api now
let { uuid, username } = await mojang.mojangDataFromUser(user)